@@ -1,7 +1,7 @@
 /*
  * Epson Inkjet Printer Driver (ESC/P-R) for Linux
  * Copyright (C) 2002-2005 AVASYS CORPORATION.
- * Copyright (C) Seiko Epson Corporation 2002-2015.
+ * Copyright (C) Seiko Epson Corporation 2002-2016.
  *
  *  This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,11 +31,8 @@
 #include <ctype.h>
 #include <errno.h>
 
-#include "epson-escpr-def.h"
-#include "epson-escpr-media.h"
 #include "epson-protocol.h"
 #include "epson-escpr-api.h"
-#include "epson-escpr-services.h"
 #include "epson-escpr-mem.h"
 
 #include "err.h"
@@ -409,10 +406,8 @@ main (int argc, char *argv[])
 
 	int page_count = 0;
 
-
 	char page_num;
 
-
 	while ((read_page_no = read (STDIN_FILENO, &page_num, 1)) > 0)  // 最初に page番号を読み込み
 	{
 		long x_count, y_count;
@@ -824,15 +819,15 @@ set_pips_parameter (filter_option_t *filter_opt_p, EPS_OPT *printOpt)
  
 	/* Brightness */
 	brightness = str_clone (filter_opt_p->brightness, strlen (filter_opt_p->brightness));
- 	jobAttr.brightness =  atoi(brightness) * 2;
+ 	jobAttr.brightness =  atoi(brightness);
 
 	/* Contrast */
 	contrast = str_clone (filter_opt_p->contrast, strlen (filter_opt_p->contrast));
- 	jobAttr.contrast =  atoi(contrast) * 2;
+ 	jobAttr.contrast =  atoi(contrast);
 
 	/* Saturation */
 	saturation = str_clone (filter_opt_p->saturation, strlen (filter_opt_p->saturation));
- 	jobAttr.saturation =  atoi(saturation) * 2;
+ 	jobAttr.saturation =  atoi(saturation);
 
 	/* Get number of pages */
 	char page_num;
@@ -890,3 +885,4 @@ EPS_INT32 print_spool_fnc(void* hParam, const EPS_UINT8* pBuf, EPS_UINT32 cbBuf)
 
 	return 1;
 }
+
